@@ -70,6 +70,7 @@ use G::Tools::Graph;
 use G::Tools::Mapping;
 use G::Tools::Blast;
 use G::Tools::Fasta;
+use G::Tools::EMBOSS;
 use G::Tools::Alignment;
 use G::Tools::HMMER;
 use G::Tools::Repeat;
@@ -122,6 +123,7 @@ push(@EXPORT, @G::Tools::Graph::EXPORT);
 push(@EXPORT, @G::Tools::Mapping::EXPORT);
 push(@EXPORT, @G::Tools::Blast::EXPORT);
 push(@EXPORT, @G::Tools::Fasta::EXPORT);
+push(@EXPORT, @G::Tools::EMBOSS::EXPORT);
 push(@EXPORT, @G::Tools::Alignment::EXPORT);
 push(@EXPORT, @G::Tools::HMMER::EXPORT);
 push(@EXPORT, @G::Tools::Repeat::EXPORT);
