@@ -208,7 +208,7 @@ sub db_save{
     if($name eq 'scratch' || db_overwrite()){
 	$dbh->do("drop table $tablename") if (db_exists($tablename));
     }else{
-	die("BDB: Database \"$name\" already exists. Aborting.");
+	die("BDB: Database \"$name\" already exists. Aborting.") if (db_exists($tablename));
     }
 
     $dbh->do("create table $tablename (BLUEBIRDid text primary key, $createtableline BLUEBIRDLonelyContent text)") || die $dbh->errstr;
