@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: G.pm,v 1.4 2002/07/30 17:40:56 gaou Exp $
@@ -32,11 +30,9 @@
 package G::DynamicLoader;
 
 use strict;
+use base qw(Exporter);
 use File::Find;
 
-require Exporter;
-
-our @ISA = qw(Exporter);
 our @EXPORT;
 
 BEGIN{
