@@ -43,7 +43,7 @@ require G::IO::EmblI;
 use File::Basename;
 use File::ShareDir ':ALL';
 
-our $VERSION = '1.8.0';
+our $VERSION = '1.8.1';
 
 #::::::::::::::::::::::::::::::
 #          Perldoc
@@ -77,6 +77,7 @@ Kazuharu Arakawa, gaou@sfc.keio.ac.jp
 my $outfile = '';
 my $loaded = 0;
 my $infile = '';
+my $this = {};
 
 #::::::::::::::::::::::::::::::
 #    Let the code begin...
@@ -100,7 +101,7 @@ sub new {
     }
 
     my @options = @_;
-    my $this = {};
+    $this = {};
     my $tmp = {};
     $infile = $filename;
     $filename =~ s/\~\//sprintf("%s\/",$ENV{HOME})/e;
@@ -282,6 +283,10 @@ sub new {
     return $this;
 }
 
+sub lastInstance {
+    return $this;
+}
+
 sub filepath {
     my $this = shift;
 
