@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: Annotation.pm,v 1.1 2002/07/30 17:44:27 gaou Exp $
@@ -33,12 +31,11 @@
 package G::IO::Annotation;
 
 use strict;
+use base qw(Exporter);
+
 use G::Messenger;
 use G::Seq::Primitive;
 
-require Exporter;
-
-our @ISA = qw(Exporter);
 our @EXPORT = qw(
 	     run_glimmer
 	     annotate_with_glimmer
