@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: GenBankI.pm,v 1.1 2002/07/30 17:44:27 gaou Exp $
@@ -32,15 +30,10 @@
 package G::IO::EmblI;
 
 use strict;
+use base qw(G::IO::Handler G::IO::GenBankO);
+
 use G::Messenger;
 
-require G::IO::Handler;
-require G::IO::GenBankO;
-
-our @ISA = qw(G::IO::Handler G::IO::GenBankO);
-
-our $VERSION = '1.0';
-
 my $infile;
 
 #::::::::::::::::::::::::::::::
@@ -355,40 +348,5 @@ sub getnucs {
 
 }
 
-
-#::::::::::::::::::::::::::::::
-#          Perldoc
-#::::::::::::::::::::::::::::::
-
 1;
 
-__END__
-
-=head1 NAME
-
-G::IO::EmblI
-
-=head1 SYNOPSIS
-
- use G::IO::EmblI;
- @ISA = (G::IO::EmblI);
-   
-=head1 DESCRIPTION
-
- EMBL input parser.
- Intended for internal use only.
-
-=back
-
-=head1 AUTHOR
-
-Kazuharu Arakawa, gaou@sfc.keio.ac.jp
-
-=head1 SEE ALSO
-
-perl(1).
-
-=cut
-
-
-
