@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: GenBankI.pm,v 1.1 2002/07/30 17:44:27 gaou Exp $
@@ -32,12 +30,11 @@
 package G::IO::FastaI;
 
 use G;
-use strict;
-use G::Messenger;
-require G::IO::Handler;
-require G::IO::GenBankO;
 
-our @ISA = qw(G::IO::Handler G::IO::GenBankO);
+use strict;
+use base qw(G::IO::Handler G::IO::GenBankO);
+
+use G::Messenger;
 
 
 #::::::::::::::::::::::::::::::
@@ -135,39 +132,5 @@ sub getnucs {
 }
 
 
-#::::::::::::::::::::::::::::::
-#          Perldoc
-#::::::::::::::::::::::::::::::
 
 1;
-
-__END__
-
-=head1 NAME
-
-G::IO::FastaI
-
-=head1 SYNOPSIS
-
- use G::IO::FastaI;
- @ISA = (G::IO::FastaI);
-   
-=head1 DESCRIPTION
-
- Fasta input parser.
- Intended for internal use only.
-
-=back
-
-=head1 AUTHOR
-
-Kazuharu Arakawa, gaou@sfc.keio.ac.jp
-
-=head1 SEE ALSO
-
-perl(1).
-
-=cut
-
-
-
