@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 # G-language GAE is free software; you can redistribute it and/or
@@ -30,17 +28,10 @@
 package G::Messenger;
 
 use strict;
-use Cwd;
-use Data::Dumper;
+use base 'Exporter';
+use autouse 'Cwd'=>qw(getcwd);
+use autouse 'Data::Dumper'=>qw(Dumper);
 
-if ('MSWin32' eq $^O){
-    eval(require Win32::InternetExplorer::Window);
-    eval(require Image::Size);
-}
-
-require Exporter;
-
-our @ISA = qw(Exporter);
 our @EXPORT = qw(
 	     msg_interface
 	     msg_ask_interface
@@ -93,6 +84,9 @@ sub msg_gimv{
 	&$gimv($file);
     }else{
 	if('MSWin32' eq $^O){
+	    require Win32::InternetExplorer::Window;
+	    require Image::Size;
+
 	    my $dir = getcwd() unless (substr($file, 0, 1) eq '/');
 	    my $filename = $dir . '/' . $file;
 	    if ($filename =~ /[htm|html]$/){
