@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: Align.pm,v 1.2 2002/07/30 17:40:56 gaou Exp $
@@ -30,14 +28,11 @@ package G::Seq::AminoAcid;
 
 use SubOpt;
 use G::Messenger;
+
 use strict;
-
+use base qw(Exporter);
 use SelfLoader;
 
-require Exporter;
-
-our @ISA = qw(Exporter);
-
 our @EXPORT = qw(
 	     calc_pI
 	     amino_info
@@ -149,7 +144,7 @@ sub
 
 =head2 peptide_mass
 
-       Author: Kazuharu Arakawa (gaou@g-language.org)
+       Author: Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
         Usage: double $mass = peptide_mass(string $aminoseq);
       Options: None.
   Description: Calculates mass of given amino acid sequence.
@@ -171,7 +166,7 @@ sub peptide_mass{
 
 =head2 calc_pI
 
-       Author: Kazuharu Arakawa (gaou@g-language.org)
+       Author: Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
         Usage: double $pI = calc_pI(string $aminoseq);
       Options: None.
   Description: Calculates isoelectric point of given amino acid sequence.
@@ -223,7 +218,7 @@ sub calc_pI{
 
 =head2 _charge
 
-       Author: Kazuharu Arakawa (gaou@g-language.org)
+       Author: Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
         Usage: $charge = charge(pK, pH) for positive
                $charge = charge(pH, pK) for negative
       Options: None.
@@ -247,7 +242,7 @@ sub _charge {
       Options: None.
   Description: Prints basic amino acid sequence information
       History: created 2001.04.04 
-               Tuned by Kazuharu Arakawa (gaou@g-language.org)
+               Tuned by Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
 =cut
 
