@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: Consensus.pm,v 1.2 2002/07/30 17:40:56 gaou Exp $
@@ -35,14 +33,9 @@ use G::Seq::Util;
 use G::Seq::Primitive;
 
 use strict;
-
-use Statistics::Descriptive;
+use base qw(Exporter);
 use SelfLoader;
 
-require Exporter;
-
-our @ISA = qw(Exporter);
-
 our @EXPORT = qw(
 	     base_counter
 	     _base_printer
@@ -751,6 +744,8 @@ sub base_individual_information_matrix{
 =cut
 
 sub consensus_z{
+    require Statistics::Descriptive;
+
     &opt_default(high=>1, low=>0.2, output=>"show", 
 		  filename=>"consensus_z.png");
     my @args = opt_get(@_);
