@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: FreeEnergy.pm,v 1.1.1.1 2002/04/02 20:25:41 gaou Exp $
@@ -33,12 +31,9 @@ use G::Messenger;
 use G::Tools::Graph;
 
 use strict;
-
+use base qw(Exporter);
 use SelfLoader;
 
-require Exporter;
-
-our @ISA = qw(Exporter);
 our @EXPORT = qw(
 	     RNAfold
 	     foreach_RNAfold
