@@ -38,6 +38,7 @@ use G::Seq::GCskew;
 use G::DB::SDB;
 
 use GD;
+use SVG;
 
 use strict;
 use base qw(Exporter);
@@ -124,12 +125,502 @@ my $cy = 4000;
 my $pi = 4 * atan2(1,1);
 
 
-__DATA__
 
 #::::::::::::::::::::::::::::::
 #        Methods Start
 #::::::::::::::::::::::::::::::
 
+
+=head2 circular_map
+
+  Name: circular_map   -   draws circular map of the genome
+
+  Description:
+   This method creates a circular map of the genome using SVG,
+   suitable for plasmids and circular bacterial chromosomes.
+
+   From the outer ring inwards, genes on direct strand (pink), 
+   genes on complementary strand (yellow), tRNAs (green arrows), 
+   rRNAs (pink or orange stripes depending on the strand), 
+   GC content (brown lines), GC skew (yellow lines). Replication 
+   origin and terminus predicted from the GC skew shift points 
+   are also labeled. 
+
+   Generated SVG is very large (8000x8000 pixels), and it is
+   suited to be converted to Google Map View with generate_gmap().
+
+   Output file is created in the "graph" directory, with 
+   the accession number as file name and ".svg" as extension.
+
+  Usage:
+    NULL = circular_map($gb);
+
+ Options:
+    None.
+
+  Author: 
+    Nobuhiro Kido (t07505nk@sfc.keio.ac.jp)
+
+  History:
+   20071023-01 initial posting
+
+=cut
+
+
+sub circular_map{
+    my $gb = opt_as_gb(shift);
+
+    mkdir( "data", 0777 );
+    mkdir( "graph",  0777 );
+
+    my $wfile = $gb->{LOCUS}->{id};
+    my ( $ori, $ter ) = find_ori_ter( $gb, -output => "/dev/null" );
+    my $bp_length = length( $gb->{SEQ} );
+    my ( $count_a, $count_b );
+
+    my $svg = SVG->new(
+        width         => $cx * 2,
+        height        => $cy * 2,
+        'xmlns:xlink' => 'http://www.w3.org/1999/xlink'
+    );
+
+    my $tag = $svg->rect(
+        width  => $cx * 2,
+        height => $cy * 2,
+        x      => 0,
+        y      => 0,
+        fill   => 'black'
+    );
+
+    my $y = $svg->group(
+        id => 'group_y',
+        style =>
+          { 'stroke' => '#ff9966', 'fill' => 'none', 'stroke-width' => 200 }
+    );
+
+    #$y->circle(cx=>$cx, cy=>$cy,r=>6500, id=>'main_c');
+
+    my $scla = $svg->group(
+        id => 'scale_a',
+        style =>
+          { 'stroke' => '#333333', 'fill' => 'none', 'stroke-width' => 1 }
+    );
+    my $sclb = $svg->group(
+        id => 'scale_b',
+        style =>
+          { 'stroke' => '#ffffff', 'fill' => 'none', 'stroke-width' => 2 }
+    );
+    my $sclc = $svg->group(
+        id => 'scale_c',
+        style =>
+          { 'stroke' => '#ffffff', 'fill' => 'none', 'stroke-width' => 2 }
+    );
+
+    my $cdsa = $svg->group(
+        id => 'cds_a',
+        style =>
+          { 'stroke' => '#cc0066', 'fill' => 'none', 'stroke-width' => 300 }
+    );
+    my $cdsb = $svg->group(
+        id => 'cds_b',
+        style =>
+          { 'stroke' => '#cc0033', 'fill' => 'none', 'stroke-width' => 300 }
+    );
+    my $cdsx = $svg->group(
+        id => 'cds_x',
+        style =>
+          { 'stroke' => '#ccff33', 'fill' => 'none', 'stroke-width' => 300 }
+    );
+    my $cdsy = $svg->group(
+        id => 'cds_y',
+        style =>
+          { 'stroke' => '#99cc00', 'fill' => 'none', 'stroke-width' => 300 }
+    );
+    my $cdst = $svg->group( id => 'cds_texts', style => { fill => '#ccccff' } );
+
+    my $trnaa = $svg->group(
+        id => 'trna_a',
+        style =>
+          { 'stroke' => '#3399ff', 'fill' => 'none', 'stroke-width' => 200 }
+    );
+    my $trnax = $svg->group(
+        id => 'trna_x',
+        style =>
+          { 'stroke' => '#00ffcc', 'fill' => 'none', 'stroke-width' => 200 }
+    );
+
+    my $yaji = $svg->group(
+        id => 'yajirushi',
+        style =>
+          { 'stroke' => '#ccffcc', 'fill' => 'none', 'stroke-width' => 5 }
+    );
+
+    my $rrnaa = $svg->group(
+        id => 'rrna_a',
+        style =>
+          { 'stroke' => '#ff6699', 'fill' => 'none', 'stroke-width' => 200 }
+    );
+    my $rrnax = $svg->group(
+        id => 'rrna_x',
+        style =>
+          { 'stroke' => '#ff9933', 'fill' => 'none', 'stroke-width' => 200 }
+    );
+
+    my $gcska = $svg->group(
+        id => 'gccontent',
+        style =>
+          { 'stroke' => '#ff9933', 'fill' => 'none', 'stroke-width' => 3 }
+    );
+    my $gcskb = $svg->group(
+        id => 'gcskew',
+        style =>
+          { 'stroke' => '#ccff66', 'fill' => 'none', 'stroke-width' => 3 }
+    );
+
+    my $oriter = $svg->group(
+        id => 'ori_ter',
+        style =>
+          { 'stroke' => '#cccc33', 'fill' => 'none', 'stroke-width' => 20 }
+    );
+
+
+    my $title = $gb->{FEATURE0}->{organism};
+
+    my $text1 = $svg->text(
+        id            => 'title',
+        'text-anchor' => 'middle',
+        x             => $cx,
+        y             => $cy,
+        fill          => '#cccccc',
+        'font-size'   => 200,
+        'font-family' => 'Gill Sans'
+    )->cdata($title);
+
+    open( PWRITER, ">./data/" . $wfile . ".coord" );
+
+    my ( $xe, $ye ) = &get_pos( $ori, 4000, $bp_length );
+    $oriter->path( 'd' => "M$cx,$cy L$xe,$ye" );
+
+    if ( $xe < $cx ) {
+        $cdst->text(
+            'text-anchor' => 'end',
+            x             => $xe,
+            y             => $ye,
+            'font-size'   => 100
+        )->cdata("ORIGIN");
+    }
+    else {
+        $cdst->text( x => $xe, y => $ye, 'font-size' => 100 )->cdata("ORIGIN");
+    }
+
+    my ( $xe, $ye ) = &get_pos( $ter, 4000, $bp_length );
+    $oriter->path( 'd' => "M$cx,$cy L$xe,$ye" );
+
+    if ( $xe < $cx ) {
+        $cdst->text(
+            'text-anchor' => 'end',
+            x             => $xe,
+            y             => $ye,
+            'font-size'   => 100
+        )->cdata("TERMINUS");
+    } else {
+        $cdst->text( x => $xe, y => $ye, 'font-size' => 100 )->cdata("TERMINUS");
+    }
+
+    my $num = $bp_length;
+    while ( $num =~ s/(.*\d)(\d\d\d)/$1,$2/ ) { }
+
+    my $text2 = $svg->text(
+        id            => 'bplength',
+        'text-anchor' => 'middle',
+        x             => $cx,
+        y             => $cy + 400,
+        fill          => '#cccccc',
+        'font-size'   => 150,
+        'font-family' => 'Gill Sans'
+    )->cdata( $num . " bp" );
+
+    my $i = 0;
+    $sclb->circle( cx => $cx, cy => $cy, r => 3750 );
+    $sclc->circle( cx => $cx, cy => $cy, r => 3680 );
+
+    while ( $i < $bp_length ) {
+        my ( $xe, $ye ) = &get_pos( $i, 3700, $bp_length );
+        $scla->path( 'd' => "M$cx,$cy L$xe,$ye" );
+        $cdst->text( x => $xe, y => $ye )->cdata( $i . "bp" );
+        my ( $xe, $ye ) = &get_pos( $i, 2850, $bp_length );
+        $cdst->text( x => $xe, y => $ye )->cdata( $i . "bp" );
+        my ( $xe, $ye ) = &get_pos( $i, 1800, $bp_length );
+        $cdst->text( x => $xe, y => $ye )->cdata( $i . "bp" );
+
+        if ( $i % 250000 == 0 ) {
+            my ( $xs, $ys ) = &get_pos( $i, 3630, $bp_length );
+            my ( $xe, $ye ) = &get_pos( $i, 3680, $bp_length );
+            $sclc->path( 'd' => "M$xs,$ys L$xe,$ye" );
+
+            $cdst->text(
+                'text-anchor' => 'middle',
+                x             => $xe,
+                y             => $ye,
+                'font-size'   => 80
+            )->cdata( $i . "bp" );
+        }
+        $i = $i + 25000;
+    }
+    for ( $i = 0 ; $i < 100 ; $i++ ) {
+        my ( $xs, $ys ) = &get_posp( $i, 3700, $bp_length );
+        my ( $xe, $ye ) = &get_posp( $i, 3750, $bp_length );
+        $sclc->path( 'd' => "M$xs,$ys L$xe,$ye" );
+
+        if ( $i % 10 == 0 ) {
+            if ( $xe < $cx ) {
+                $cdst->text(
+                    'text-anchor' => 'end',
+                    x             => $xe,
+                    y             => $ye,
+                    'font-size'   => 80
+                )->cdata( $i, "\%" );
+            } else {
+                $cdst->text( x => $xe, y => $ye, 'font-size' => 80 )->cdata( $i, "\%" );
+            }
+        }
+    }
+
+    for my $feature ( $gb->feature() ) {
+        if ( $gb->{$feature}->{type} eq "gene" and $gb->{$feature}->{direction} eq "direct" ) {
+            $count_a++;
+            my $r = 3400;
+            my ( $xs, $ys ) = &get_pos( $gb->{$feature}->{start}, $r, $bp_length );
+            my ( $xe, $ye ) = &get_pos( $gb->{$feature}->{end}, $r, $bp_length );
+
+            if ( $count_a % 2 == 1 ) {
+                $cdsa->path(
+                    id  => "a" . $count_a,
+                    'd' => "M$xs $ys A$r $r,0,0 1,$xe $ye"
+                );
+            } else {
+                $cdsb->path(
+                    id  => "a" . $count_a,
+                    'd' => "M$xs $ys A$r $r,0,0 1,$xe $ye"
+                );
+            }
+
+            my ( $xm, $ym ) = &get_mapp( ( $xs + $xe ) / 2, ( $ys + $ye ) / 2, $bp_length );
+	    my $feat = $gb->next_feature($feature);
+            printf PWRITER "%s\t%s\t%s\t%d\t%d\n", $feat, $gb->{$feat}->{type}, $gb->{$feat}->{gene}, $xm, $ym;
+        }
+
+        if ( $gb->{$feature}->{type} eq "gene" and $gb->{$feature}->{direction} eq "complement" ){
+            $count_b++;
+            my $r = 3100;
+            my ( $xs, $ys ) = &get_pos( $gb->{$feature}->{start}, $r, $bp_length );
+            my ( $xe, $ye ) = &get_pos( $gb->{$feature}->{end}, $r, $bp_length );
+
+            if ( $count_b % 2 == 1 ) {
+                $cdsx->path(
+                    id  => "b" . $count_b,
+                    'd' => "M$xs $ys A$r $r,0,0 1,$xe $ye"
+                );
+            } else {
+                $cdsy->path(
+                    id  => "b" . $count_b,
+                    'd' => "M$xs $ys A$r $r,0,0 1,$xe $ye"
+                );
+            }
+
+            my ( $xm, $ym ) = &get_mapp( ( $xs + $xe ) / 2, ( $ys + $ye ) / 2, $bp_length );
+
+	    my $feat = $gb->next_feature($feature);
+            printf PWRITER "%s\t%s\t%s\t%d\t%d\n", $feat, $gb->{$feat}->{type}, $gb->{$feat}->{gene}, $xm, $ym;
+        }
+
+        if ( $gb->{$feature}->{type} eq "tRNA" and $gb->{$feature}->{direction} eq "direct" ){
+            my $r = 2600;
+            my ( $xs, $ys ) = &get_pos( $gb->{$feature}->{start}, $r, $bp_length );
+            my ( $xe, $ye ) = &get_pos( $gb->{$feature}->{end}, $r, $bp_length );
+            $trnaa->path( 'd' => "M$xs $ys A$r $r,0,0 1,$xe $ye" );
+            my ( $xxs, $yys, $xxe, $yye, $xl, $yl, $xr, $yr ) = &get_arrow( $gb->{$feature}->{start}, $r + 50, $bp_length );
+            $yaji->path( 'd' => "M$xxs $yys L$xxe $yye" );
+            $yaji->path( 'd' => "M$xxe $yye L$xl $yl" );
+            $yaji->path( 'd' => "M$xxe $yye L$xr $yr" );
+        }
+
+        if ( $gb->{$feature}->{type} eq "tRNA" and $gb->{$feature}->{direction} eq "complement" ){
+            my $r = 2600;
+            my ( $xs, $ys ) = &get_pos( $gb->{$feature}->{start}, $r, $bp_length );
+            my ( $xe, $ye ) = &get_pos( $gb->{$feature}->{end}, $r, $bp_length );
+            $trnax->path( 'd' => "M$xs $ys A$r $r,0,0 1,$xe $ye" );
+            my ( $xxs, $yys, $xxe, $yye, $xl, $yl, $xr, $yr ) = &get_arrowc( $gb->{$feature}->{start}, $r - 50, $bp_length );
+            $yaji->path( 'd' => "M$xxs $yys L$xxe $yye" );
+            $yaji->path( 'd' => "M$xxs $yys L$xl $yl" );
+            $yaji->path( 'd' => "M$xxs $yys L$xr $yr" );
+        }
+
+        if ( $gb->{$feature}->{type} eq "rRNA" and $gb->{$feature}->{direction} eq "direct" ){
+            my $r = 2400;
+            my ( $xs, $ys ) = &get_pos( $gb->{$feature}->{start}, $r, $bp_length );
+            my ( $xe, $ye ) = &get_pos( $gb->{$feature}->{end}, $r, $bp_length );
+            $rrnaa->path( 'd' => "M$xs $ys A$r $r,0,0 1,$xe $ye" );
+        }
+
+        if ( $gb->{$feature}->{type} eq "rRNA" and $gb->{$feature}->{direction} eq "complement" ){
+            my $r = 2400;
+            my ( $xs, $ys ) = &get_pos( $gb->{$feature}->{start}, $r, $bp_length );
+            my ( $xe, $ye ) = &get_pos( $gb->{$feature}->{end}, $r, $bp_length );
+            $rrnax->path( 'd' => "M$xs $ys A$r $r,0,0 1,$xe $ye" );
+        }
+    }
+
+    my $bline  = 2000;
+    my $blineg = 1500;
+    my ( $px,  $py )  = &get_pos( 0, $bline,  $bp_length );
+    my ( $pxg, $pyg ) = &get_pos( 0, $blineg, $bp_length );
+
+    my $range = 1000;
+    my $wsize = 2000;           #window_bp_size
+    my $step  = 1000;
+
+    my $tag   = $svg->circle(
+        cx     => $cx,
+        cy     => $cy,
+        r      => $bline,
+        stroke => '#33ff99',
+        fill   => 'none'
+    );
+
+    my $tag = $svg->circle(
+        cx     => $cx,
+        cy     => $cy,
+        r      => $blineg,
+        stroke => '#66ffff',
+        fill   => 'none'
+    );
+
+    for ( my $i = 0 ; $i + $wsize <= $bp_length ; $i += $step ) {
+        my $temp = substr( $gb->{SEQ}, $i, $wsize );
+        my $c_g = $temp =~ tr/g/g/;
+        my $c_c = $temp =~ tr/c/c/;
+        my $c_a = $temp =~ tr/a/a/;
+        my $c_t = $temp =~ tr/t/t/;
+
+        my $gc_content = 0;
+        $gc_content = ( $c_g + $c_c ) / ( $c_g + $c_c + $c_a + $c_t )
+          if ( $c_g + $c_c + $c_a + $c_t );
+
+        my ( $x, $y ) = &get_pos( $i, ( $bline + ( $gc_content - 0.5 ) * $range * 2 ), $bp_length );
+
+        my $gc_skew = 0;
+        $gc_skew = ( $c_c - $c_g ) / ( $c_g + $c_c ) if ( $c_g + $c_c );
+
+        my ( $xg, $yg ) = &get_pos( $i, ( $blineg + ($gc_skew) * $range * 2 ), $bp_length );
+
+        $gcska->path( 'd' => "M$px,$py L$x,$y" );
+
+        $px = $x;
+        $py = $y;
+        $gcskb->path( 'd' => "M$pxg,$pyg L$xg,$yg" );
+
+        $pxg = $xg;
+        $pyg = $yg;
+    }
+
+    $cdst->text(
+        'text-anchor' => 'middle',
+        x             => $cx,
+        y             => 1750,
+        'font-size'   => 120
+    )->cdata("GC-contents");
+
+    $cdst->text(
+        'text-anchor' => 'middle',
+        x             => $cx,
+        y             => 3000,
+        'font-size'   => 120
+    )->cdata("GC-skew");
+
+    close PWRITER;
+    open( WRITER, ">./graph/" . $wfile . ".svg" );
+    print WRITER $svg->xmlify;
+    close WRITER;
+}
+
+sub get_pos {
+    my ( $n, $r, $bp_length ) = @_;
+    my $x = $cx + ( sin( 2 * $pi * $n / $bp_length ) * $r );
+    my $y = $cy - ( cos( 2 * $pi * $n / $bp_length ) * $r );
+
+    return ( $x, $y );
+}
+
+sub get_posp {
+    my ( $n, $r, $bp_length ) = @_;
+    my $x = $cx + ( sin( 2 * $pi * $n / 100 ) * $r );
+    my $y = $cy - ( cos( 2 * $pi * $n / 100 ) * $r );
+
+    return ( $x, $y );
+}
+
+sub get_mapp {
+    my ( $n, $r, $bp_length ) = @_;
+    my $x = $n * 8192 / 8000;
+    my $y = $r * 8192 / 8000;
+
+    return ( $x, $y );
+}
+
+sub get_arrow {
+    my ( $n, $r, $bp_length ) = @_;
+
+    my $rr = 40;                                                #length
+    my $rl = 20;                                                #hand_length
+    my $x  = $cx + ( sin( 2 * $pi * $n / $bp_length ) * $r );
+    my $y  = $cy - ( cos( 2 * $pi * $n / $bp_length ) * $r );
+    my $th  = 2 * $pi * ( 1 + $n ) / $bp_length;
+    my $xxs = $x - cos($th) * $rr;
+    my $yys = $y - sin($th) * $rr;
+    my $xxe = $x + cos($th) * $rr;
+    my $yye = $y + sin($th) * $rr;
+
+    $th -= $pi * 3 / 4;
+    my $xl = $xxe + cos($th) * $rl;
+    my $yl = $yye + sin($th) * $rl;
+    my $th -= $pi * 2 / 4;
+    my $xr = $xxe + cos($th) * $rl;
+    my $yr = $yye + sin($th) * $rl;
+
+    return ( $xxs, $yys, $xxe, $yye, $xl, $yl, $xr, $yr );
+}
+
+sub get_arrowc {
+    my ( $n, $r, $bp_length ) = @_;
+
+    my $rr = 40;                                                #length
+    my $rl = 20;                                                #hand_length
+    my $x  = $cx + ( sin( 2 * $pi * $n / $bp_length ) * $r );
+    my $y  = $cy - ( cos( 2 * $pi * $n / $bp_length ) * $r );
+    my $th  = 2 * $pi * ( 1 + $n ) / $bp_length;
+    my $xxs = $x - cos($th) * $rr;
+    my $yys = $y - sin($th) * $rr;
+    my $xxe = $x + cos($th) * $rr;
+    my $yye = $y + sin($th) * $rr;
+    
+    $th -= $pi * 1 / 4;
+    my $xl = $xxs + cos($th) * $rl;
+    my $yl = $yys + sin($th) * $rl;
+    my $th += $pi * 2 / 4;
+    my $xr = $xxs + cos($th) * $rl;
+    my $yr = $yys + sin($th) * $rl;
+
+    return ( $xxs, $yys, $xxe, $yye, $xl, $yl, $xr, $yr );
+}
+
+
+
+
+
+__DATA__
+
+
 =head2 genome_map
 
   Name: genome_map   -   draws the map of the genome
@@ -934,7 +1425,7 @@ sub genome_map3 {
     my $window = int(length($gb->{SEQ}) / ($numHBlock * $numVBlock * $hblock)) + 1;
 
     msg_error("Image size: $width x $height pixels.\nUsing Window size = $window bp to fit the whole genome...\n\n");
-    msg_error("Map generation will take a few minutes. Please make yourself comfortable until the image is generated ;-\)\n\n");
+    msg_error("Map generation will take a few minutes. Please make yourself comfortable until the image is generated ;-\)\n\n") if ($gmap);
 
     my $start = 1;
     my $end = length $gb->{SEQ};
@@ -947,22 +1438,22 @@ sub genome_map3 {
 
     # GD constant
     my $im = new GD::Image($width, $height);
-    my $white = $im->colorAllocate(255,255,255);
-    my $black = $im->colorAllocate(0,0,0);
-    my $gray = $im->colorAllocate(180,180,180);  
-    my $red = $im->colorAllocate(255,0,0);       #A
+    my $white  = $im->colorAllocate(255,255,255);
+    my $black  = $im->colorAllocate(0,0,0);
+    my $gray   = $im->colorAllocate(180,180,180);  
+    my $red    = $im->colorAllocate(255,0,0);    #A
     my $yellow = $im->colorAllocate(255,255,0);  #G
-    my $green = $im->colorAllocate(0,150,0);     #T
-    my $blue = $im->colorAllocate(0,0,255);      #C
-    my $aqua = $im->colorAllocate(120, 160, 255);
-    my $rrna = $im->colorAllocate(255, 160, 160);
-    my $trna = $im->colorAllocate(160, 255, 160);
+    my $green  = $im->colorAllocate(0,150,0);    #T
+    my $blue   = $im->colorAllocate(0,0,255);    #C
+    my $aqua   = $im->colorAllocate(120, 160, 255);
+    my $rrna   = $im->colorAllocate(255, 160, 160);
+    my $trna   = $im->colorAllocate(160, 255, 160);
 
-    my $gred = $im->colorAllocate(255,200,200);       #A for graph
-    my $gyellow = $im->colorAllocate(255,255,100);    #G for graph
-    my $ggreen = $im->colorAllocate(180,220,180);     #T for graph
-    my $gblue = $im->colorAllocate(200,200,255);      #C for graph
-    
+    my $gred    = $im->colorAllocate(255,200,200);   #A for graph
+    my $gyellow = $im->colorAllocate(255,255,100);   #G for graph
+    my $ggreen  = $im->colorAllocate(180,220,180);   #T for graph
+    my $gblue   = $im->colorAllocate(200,200,255);   #C for graph
+  
 
     # Draw Base Graph
     for ($i = $sidemargin; $i <= $sidemargin + $hblock * $numHBlock; $i += $hblock){
@@ -1110,12 +1601,12 @@ sub genome_map3 {
 	    }
 
 	    if($cdsdir eq 'complement'){
-		printf OUT "%s\t%s\t%s\t%s\t%s\n", $feat, $sidemargin + ($cdsstart / $window) % ($hblock * $numHBlock),
+		printf OUT "%s\t%s\t%s\t%s\t%s\t%s\n", $feat, $gb->{$feat}->{type}, $sidemargin + ($cdsstart / $window) % ($hblock * $numHBlock),
 		$topmargin + $dif1 + (int(($cdsstart / $window) / ($hblock * $numHBlock))+1) * $vblock * 5,
 		$sidemargin + ($cdsend / $window) % ($hblock * $numHBlock),
 		$topmargin + $dif2 + (int(($cdsend / $window) / ($hblock * $numHBlock))+1) * $vblock * 5;
 	    }else{
-		printf OUT "%s\t%s\t%s\t%s\t%s\n", $feat, $sidemargin + ($cdsstart / $window) % ($hblock * $numHBlock),
+		printf OUT "%s\t%s\t%s\t%s\t%s\t%s\n", $feat, $gb->{$feat}->{type}, $sidemargin + ($cdsstart / $window) % ($hblock * $numHBlock),
 		$topmargin + $dif2 + (int(($cdsstart / $window) / ($hblock * $numHBlock))+1) * $vblock * 5,
 		$sidemargin + ($cdsend / $window) % ($hblock * $numHBlock),
 		$topmargin + $dif1 + (int(($cdsend / $window) / ($hblock * $numHBlock))+1) * $vblock * 5;
@@ -1460,496 +1951,6 @@ sub plasmid_map{
 
 
 
-=head2 circular_map
-
-  Name: circular_map   -   draws circular map of the genome
-
-  Description:
-   This method creates a circular map of the genome using SVG,
-   suitable for plasmids and circular bacterial chromosomes.
-
-   From the outer ring inwards, genes on direct strand (pink), 
-   genes on complementary strand (yellow), tRNAs (green arrows), 
-   rRNAs (pink or orange stripes depending on the strand), 
-   GC content (brown lines), GC skew (yellow lines). Replication 
-   origin and terminus predicted from the GC skew shift points 
-   are also labeled. 
-
-   Generated SVG is very large (8000x8000 pixels), and it is
-   suited to be converted to Google Map View with generate_gmap().
-
-   Output file is created in the "graph" directory, with 
-   the accession number as file name and ".svg" as extension.
-
-  Usage:
-    NULL = circular_map($gb);
-
- Options:
-    None.
-
-  Author: 
-    Nobuhiro Kido (t07505nk@sfc.keio.ac.jp)
-
-  History:
-   20071023-01 initial posting
-
-=cut
-
-
-sub circular_map{
-    require SVG;
-
-    my $gb = opt_as_gb(shift);
-
-    mkdir( "data", 0777 );
-    mkdir( "graph",  0777 );
-
-    my $wfile = $gb->{LOCUS}->{id};
-    my ( $ori, $ter ) = find_ori_ter( $gb, -output => "/dev/null" );
-    my $bp_length = length( $gb->{SEQ} );
-    my ( $count_a, $count_b );
-
-    my $svg = SVG->new(
-        width         => $cx * 2,
-        height        => $cy * 2,
-        'xmlns:xlink' => 'http://www.w3.org/1999/xlink'
-    );
-
-    my $tag = $svg->rect(
-        width  => $cx * 2,
-        height => $cy * 2,
-        x      => 0,
-        y      => 0,
-        fill   => 'black'
-    );
-
-    my $y = $svg->group(
-        id => 'group_y',
-        style =>
-          { 'stroke' => '#ff9966', 'fill' => 'none', 'stroke-width' => 200 }
-    );
-
-    #$y->circle(cx=>$cx, cy=>$cy,r=>6500, id=>'main_c');
-
-    my $scla = $svg->group(
-        id => 'scale_a',
-        style =>
-          { 'stroke' => '#333333', 'fill' => 'none', 'stroke-width' => 1 }
-    );
-    my $sclb = $svg->group(
-        id => 'scale_b',
-        style =>
-          { 'stroke' => '#ffffff', 'fill' => 'none', 'stroke-width' => 2 }
-    );
-    my $sclc = $svg->group(
-        id => 'scale_c',
-        style =>
-          { 'stroke' => '#ffffff', 'fill' => 'none', 'stroke-width' => 2 }
-    );
-
-    my $cdsa = $svg->group(
-        id => 'cds_a',
-        style =>
-          { 'stroke' => '#cc0066', 'fill' => 'none', 'stroke-width' => 300 }
-    );
-    my $cdsb = $svg->group(
-        id => 'cds_b',
-        style =>
-          { 'stroke' => '#cc0033', 'fill' => 'none', 'stroke-width' => 300 }
-    );
-    my $cdsx = $svg->group(
-        id => 'cds_x',
-        style =>
-          { 'stroke' => '#ccff33', 'fill' => 'none', 'stroke-width' => 300 }
-    );
-    my $cdsy = $svg->group(
-        id => 'cds_y',
-        style =>
-          { 'stroke' => '#99cc00', 'fill' => 'none', 'stroke-width' => 300 }
-    );
-    my $cdst = $svg->group( id => 'cds_texts', style => { fill => '#ccccff' } );
-
-    my $trnaa = $svg->group(
-        id => 'trna_a',
-        style =>
-          { 'stroke' => '#3399ff', 'fill' => 'none', 'stroke-width' => 200 }
-    );
-    my $trnax = $svg->group(
-        id => 'trna_x',
-        style =>
-          { 'stroke' => '#00ffcc', 'fill' => 'none', 'stroke-width' => 200 }
-    );
-
-    my $yaji = $svg->group(
-        id => 'yajirushi',
-        style =>
-          { 'stroke' => '#ccffcc', 'fill' => 'none', 'stroke-width' => 5 }
-    );
-
-    my $rrnaa = $svg->group(
-        id => 'rrna_a',
-        style =>
-          { 'stroke' => '#ff6699', 'fill' => 'none', 'stroke-width' => 200 }
-    );
-    my $rrnax = $svg->group(
-        id => 'rrna_x',
-        style =>
-          { 'stroke' => '#ff9933', 'fill' => 'none', 'stroke-width' => 200 }
-    );
-
-    my $gcska = $svg->group(
-        id => 'gccontent',
-        style =>
-          { 'stroke' => '#ff9933', 'fill' => 'none', 'stroke-width' => 3 }
-    );
-    my $gcskb = $svg->group(
-        id => 'gcskew',
-        style =>
-          { 'stroke' => '#ccff66', 'fill' => 'none', 'stroke-width' => 3 }
-    );
-
-    my $oriter = $svg->group(
-        id => 'ori_ter',
-        style =>
-          { 'stroke' => '#cccc33', 'fill' => 'none', 'stroke-width' => 20 }
-    );
-
-
-    my $title = $gb->{FEATURE0}->{organism};
-
-    my $text1 = $svg->text(
-        id            => 'title',
-        'text-anchor' => 'middle',
-        x             => $cx,
-        y             => $cy,
-        fill          => '#cccccc',
-        'font-size'   => 200,
-        'font-family' => 'Gill Sans'
-    )->cdata($title);
-
-    open( PWRITER, ">./data/" . $wfile . ".coord" );
-
-    my ( $xe, $ye ) = &get_pos( $ori, 4000, $bp_length );
-    $oriter->path( 'd' => "M$cx,$cy L$xe,$ye" );
-
-    if ( $xe < $cx ) {
-        $cdst->text(
-            'text-anchor' => 'end',
-            x             => $xe,
-            y             => $ye,
-            'font-size'   => 100
-        )->cdata("ORIGIN");
-    }
-    else {
-        $cdst->text( x => $xe, y => $ye, 'font-size' => 100 )->cdata("ORIGIN");
-    }
-
-    my ( $xe, $ye ) = &get_pos( $ter, 4000, $bp_length );
-    $oriter->path( 'd' => "M$cx,$cy L$xe,$ye" );
-
-    if ( $xe < $cx ) {
-        $cdst->text(
-            'text-anchor' => 'end',
-            x             => $xe,
-            y             => $ye,
-            'font-size'   => 100
-        )->cdata("TERMINUS");
-    } else {
-        $cdst->text( x => $xe, y => $ye, 'font-size' => 100 )->cdata("TERMINUS");
-    }
-
-    my $num = $bp_length;
-    while ( $num =~ s/(.*\d)(\d\d\d)/$1,$2/ ) { }
-
-    my $text2 = $svg->text(
-        id            => 'bplength',
-        'text-anchor' => 'middle',
-        x             => $cx,
-        y             => $cy + 400,
-        fill          => '#cccccc',
-        'font-size'   => 150,
-        'font-family' => 'Gill Sans'
-    )->cdata( $num . " bp" );
-
-    my $i = 0;
-    $sclb->circle( cx => $cx, cy => $cy, r => 3750 );
-    $sclc->circle( cx => $cx, cy => $cy, r => 3680 );
-
-    while ( $i < $bp_length ) {
-        my ( $xe, $ye ) = &get_pos( $i, 3700, $bp_length );
-        $scla->path( 'd' => "M$cx,$cy L$xe,$ye" );
-        $cdst->text( x => $xe, y => $ye )->cdata( $i . "bp" );
-        my ( $xe, $ye ) = &get_pos( $i, 2850, $bp_length );
-        $cdst->text( x => $xe, y => $ye )->cdata( $i . "bp" );
-        my ( $xe, $ye ) = &get_pos( $i, 1800, $bp_length );
-        $cdst->text( x => $xe, y => $ye )->cdata( $i . "bp" );
-
-        if ( $i % 250000 == 0 ) {
-            my ( $xs, $ys ) = &get_pos( $i, 3630, $bp_length );
-            my ( $xe, $ye ) = &get_pos( $i, 3680, $bp_length );
-            $sclc->path( 'd' => "M$xs,$ys L$xe,$ye" );
-
-            $cdst->text(
-                'text-anchor' => 'middle',
-                x             => $xe,
-                y             => $ye,
-                'font-size'   => 80
-            )->cdata( $i . "bp" );
-        }
-        $i = $i + 25000;
-    }
-    for ( $i = 0 ; $i < 100 ; $i++ ) {
-        my ( $xs, $ys ) = &get_posp( $i, 3700, $bp_length );
-        my ( $xe, $ye ) = &get_posp( $i, 3750, $bp_length );
-        $sclc->path( 'd' => "M$xs,$ys L$xe,$ye" );
-
-        if ( $i % 10 == 0 ) {
-            if ( $xe < $cx ) {
-                $cdst->text(
-                    'text-anchor' => 'end',
-                    x             => $xe,
-                    y             => $ye,
-                    'font-size'   => 80
-                )->cdata( $i, "\%" );
-            } else {
-                $cdst->text( x => $xe, y => $ye, 'font-size' => 80 )->cdata( $i, "\%" );
-            }
-        }
-    }
-
-    for my $feature ( $gb->feature() ) {
-        if ( $gb->{$feature}->{type} eq "gene" and $gb->{$feature}->{direction} eq "direct" ) {
-            $count_a++;
-            my $r = 3400;
-            my ( $xs, $ys ) = &get_pos( $gb->{$feature}->{start}, $r, $bp_length );
-            my ( $xe, $ye ) = &get_pos( $gb->{$feature}->{end}, $r, $bp_length );
-
-            if ( $count_a % 2 == 1 ) {
-                $cdsa->path(
-                    id  => "a" . $count_a,
-                    'd' => "M$xs $ys A$r $r,0,0 1,$xe $ye"
-                );
-            } else {
-                $cdsb->path(
-                    id  => "a" . $count_a,
-                    'd' => "M$xs $ys A$r $r,0,0 1,$xe $ye"
-                );
-            }
-
-            my ( $xm, $ym ) = &get_mapp( ( $xs + $xe ) / 2, ( $ys + $ye ) / 2, $bp_length );
-            print PWRITER "$feature\t$gb->{$feature}->{gene}\t$xm\t$ym\n";
-
-        }
-
-        if ( $gb->{$feature}->{type} eq "gene" and $gb->{$feature}->{direction} eq "complement" ){
-            $count_b++;
-            my $r = 3100;
-            my ( $xs, $ys ) = &get_pos( $gb->{$feature}->{start}, $r, $bp_length );
-            my ( $xe, $ye ) = &get_pos( $gb->{$feature}->{end}, $r, $bp_length );
-
-            if ( $count_b % 2 == 1 ) {
-                $cdsx->path(
-                    id  => "b" . $count_b,
-                    'd' => "M$xs $ys A$r $r,0,0 1,$xe $ye"
-                );
-            } else {
-                $cdsy->path(
-                    id  => "b" . $count_b,
-                    'd' => "M$xs $ys A$r $r,0,0 1,$xe $ye"
-                );
-            }
-
-            my ( $xm, $ym ) = &get_mapp( ( $xs + $xe ) / 2, ( $ys + $ye ) / 2, $bp_length );
-            print PWRITER "$feature\t$gb->{$feature}->{gene}\t$xm\t$ym\n";
-
-        }
-
-        if ( $gb->{$feature}->{type} eq "tRNA" and $gb->{$feature}->{direction} eq "direct" ){
-            my $r = 2600;
-            my ( $xs, $ys ) = &get_pos( $gb->{$feature}->{start}, $r, $bp_length );
-            my ( $xe, $ye ) = &get_pos( $gb->{$feature}->{end}, $r, $bp_length );
-            $trnaa->path( 'd' => "M$xs $ys A$r $r,0,0 1,$xe $ye" );
-            my ( $xxs, $yys, $xxe, $yye, $xl, $yl, $xr, $yr ) = &get_arrow( $gb->{$feature}->{start}, $r + 50, $bp_length );
-            $yaji->path( 'd' => "M$xxs $yys L$xxe $yye" );
-            $yaji->path( 'd' => "M$xxe $yye L$xl $yl" );
-            $yaji->path( 'd' => "M$xxe $yye L$xr $yr" );
-        }
-
-        if ( $gb->{$feature}->{type} eq "tRNA" and $gb->{$feature}->{direction} eq "complement" ){
-            my $r = 2600;
-            my ( $xs, $ys ) = &get_pos( $gb->{$feature}->{start}, $r, $bp_length );
-            my ( $xe, $ye ) = &get_pos( $gb->{$feature}->{end}, $r, $bp_length );
-            $trnax->path( 'd' => "M$xs $ys A$r $r,0,0 1,$xe $ye" );
-            my ( $xxs, $yys, $xxe, $yye, $xl, $yl, $xr, $yr ) = &get_arrowc( $gb->{$feature}->{start}, $r - 50, $bp_length );
-            $yaji->path( 'd' => "M$xxs $yys L$xxe $yye" );
-            $yaji->path( 'd' => "M$xxs $yys L$xl $yl" );
-            $yaji->path( 'd' => "M$xxs $yys L$xr $yr" );
-        }
-
-        if ( $gb->{$feature}->{type} eq "rRNA" and $gb->{$feature}->{direction} eq "direct" ){
-            my $r = 2400;
-            my ( $xs, $ys ) = &get_pos( $gb->{$feature}->{start}, $r, $bp_length );
-            my ( $xe, $ye ) = &get_pos( $gb->{$feature}->{end}, $r, $bp_length );
-            $rrnaa->path( 'd' => "M$xs $ys A$r $r,0,0 1,$xe $ye" );
-        }
-
-        if ( $gb->{$feature}->{type} eq "rRNA" and $gb->{$feature}->{direction} eq "complement" ){
-            my $r = 2400;
-            my ( $xs, $ys ) =
-              &get_pos( $gb->{$feature}->{start}, $r, $bp_length );
-            my ( $xe, $ye ) =
-              &get_pos( $gb->{$feature}->{end}, $r, $bp_length );
-            $rrnax->path( 'd' => "M$xs $ys A$r $r,0,0 1,$xe $ye" );
-        }
-    }
-
-    my $bline  = 2000;
-    my $blineg = 1500;
-    my ( $px,  $py )  = &get_pos( 0, $bline,  $bp_length );
-    my ( $pxg, $pyg ) = &get_pos( 0, $blineg, $bp_length );
-
-    my $range = 1000;
-    my $wsize = 2000;           #window_bp_size
-    my $step  = 1000;
-
-    my $tag   = $svg->circle(
-        cx     => $cx,
-        cy     => $cy,
-        r      => $bline,
-        stroke => '#33ff99',
-        fill   => 'none'
-    );
-
-    my $tag = $svg->circle(
-        cx     => $cx,
-        cy     => $cy,
-        r      => $blineg,
-        stroke => '#66ffff',
-        fill   => 'none'
-    );
-
-    for ( my $i = 0 ; $i + $wsize <= $bp_length ; $i += $step ) {
-        my $temp = substr( $gb->{SEQ}, $i, $wsize );
-        my $c_g = $temp =~ tr/g/g/;
-        my $c_c = $temp =~ tr/c/c/;
-        my $c_a = $temp =~ tr/a/a/;
-        my $c_t = $temp =~ tr/t/t/;
-
-        my $gc_content = 0;
-        $gc_content = ( $c_g + $c_c ) / ( $c_g + $c_c + $c_a + $c_t )
-          if ( $c_g + $c_c + $c_a + $c_t );
-
-        my ( $x, $y ) = &get_pos( $i, ( $bline + ( $gc_content - 0.5 ) * $range * 2 ), $bp_length );
-
-        my $gc_skew = 0;
-        $gc_skew = ( $c_c - $c_g ) / ( $c_g + $c_c ) if ( $c_g + $c_c );
-
-        my ( $xg, $yg ) = &get_pos( $i, ( $blineg + ($gc_skew) * $range * 2 ), $bp_length );
-
-        $gcska->path( 'd' => "M$px,$py L$x,$y" );
-
-        $px = $x;
-        $py = $y;
-        $gcskb->path( 'd' => "M$pxg,$pyg L$xg,$yg" );
-
-        $pxg = $xg;
-        $pyg = $yg;
-    }
-
-    $cdst->text(
-        'text-anchor' => 'middle',
-        x             => $cx,
-        y             => 1750,
-        'font-size'   => 120
-    )->cdata("GC-contents");
-
-    $cdst->text(
-        'text-anchor' => 'middle',
-        x             => $cx,
-        y             => 3000,
-        'font-size'   => 120
-    )->cdata("GC-skew");
-
-    close PWRITER;
-    open( WRITER, ">./graph/" . $wfile . ".svg" );
-    print WRITER $svg->xmlify;
-    close WRITER;
-}
-
-sub get_pos {
-    my ( $n, $r, $bp_length ) = @_;
-    my $x = $cx + ( sin( 2 * $pi * $n / $bp_length ) * $r );
-    my $y = $cy - ( cos( 2 * $pi * $n / $bp_length ) * $r );
-
-    return ( $x, $y );
-}
-
-sub get_posp {
-    my ( $n, $r, $bp_length ) = @_;
-    my $x = $cx + ( sin( 2 * $pi * $n / 100 ) * $r );
-    my $y = $cy - ( cos( 2 * $pi * $n / 100 ) * $r );
-
-    return ( $x, $y );
-}
-
-sub get_mapp {
-    my ( $n, $r, $bp_length ) = @_;
-    my $x = $n * 8192 / 8000;
-    my $y = $r * 8192 / 8000;
-
-    return ( $x, $y );
-}
-
-sub get_arrow {
-    my ( $n, $r, $bp_length ) = @_;
-
-    my $rr = 40;                                                #length
-    my $rl = 20;                                                #hand_length
-    my $x  = $cx + ( sin( 2 * $pi * $n / $bp_length ) * $r );
-    my $y  = $cy - ( cos( 2 * $pi * $n / $bp_length ) * $r );
-    my $th  = 2 * $pi * ( 1 + $n ) / $bp_length;
-    my $xxs = $x - cos($th) * $rr;
-    my $yys = $y - sin($th) * $rr;
-    my $xxe = $x + cos($th) * $rr;
-    my $yye = $y + sin($th) * $rr;
-
-    $th -= $pi * 3 / 4;
-    my $xl = $xxe + cos($th) * $rl;
-    my $yl = $yye + sin($th) * $rl;
-    my $th -= $pi * 2 / 4;
-    my $xr = $xxe + cos($th) * $rl;
-    my $yr = $yye + sin($th) * $rl;
-
-    return ( $xxs, $yys, $xxe, $yye, $xl, $yl, $xr, $yr );
-}
-
-sub get_arrowc {
-    my ( $n, $r, $bp_length ) = @_;
-
-    my $rr = 40;                                                #length
-    my $rl = 20;                                                #hand_length
-    my $x  = $cx + ( sin( 2 * $pi * $n / $bp_length ) * $r );
-    my $y  = $cy - ( cos( 2 * $pi * $n / $bp_length ) * $r );
-    my $th  = 2 * $pi * ( 1 + $n ) / $bp_length;
-    my $xxs = $x - cos($th) * $rr;
-    my $yys = $y - sin($th) * $rr;
-    my $xxe = $x + cos($th) * $rr;
-    my $yye = $y + sin($th) * $rr;
-    
-    $th -= $pi * 1 / 4;
-    my $xl = $xxs + cos($th) * $rl;
-    my $yl = $yys + sin($th) * $rl;
-    my $th += $pi * 2 / 4;
-    my $xr = $xxs + cos($th) * $rl;
-    my $yr = $yys + sin($th) * $rl;
-
-    return ( $xxs, $yys, $xxe, $yye, $xl, $yl, $xr, $yr );
-}
-
-
-
-
-
 
 
 
@@ -2103,7 +2104,8 @@ sub dnawalk{
 	$cds_x = int ($cx + @pos_x[$gb->{$cds}->{start}] / $compress);
 	$cds_y = int ($cy + @pos_y[$gb->{$cds}->{start}] / $compress);
 	my $gene = $gb->{$cds}->{gene} or $gb->{$cds}->{locus_tag};
-	print DATA "$cds\t$gene\t$cds_x\t$cds_y\n";	
+	my $type = $gb->{$cds}->{type};
+	print DATA "$cds\t$type\t$gene\t$cds_x\t$cds_y\n";	
     }
     close DATA;   
     
