@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: Tandem.pm,v 1.1.1.1 2002/04/02 20:25:42 gaou Exp $
@@ -32,13 +30,11 @@ use SubOpt;
 use G::Messenger;
 
 use GD;
-use strict;
 
+use strict;
+use base qw(Exporter);
 use SelfLoader;
 
-require Exporter;
-
-our @ISA = qw(Exporter);
 our @EXPORT = qw(
 		 find_tandem
 		 foreach_tandem
