@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: Util.pm,v 1.1.1.1 2002/04/02 20:25:43 gaou Exp $
@@ -39,13 +37,10 @@ use G::IO;
 use G::IO::Annotation;
 
 use strict;
-use Cwd;
+use base qw(Exporter);
+use autouse 'Cwd'=>qw(getcwd);
 use SelfLoader;
 
-require Exporter;
-
-our @ISA = qw(Exporter);
-
 our @EXPORT = qw(
 		 find_king_of_gene
 		 seqinfo
