@@ -31,6 +31,8 @@ use strict;
 use base qw(Exporter);
 use autouse 'String::Approx'=>qw(amatch);
 use File::Find;
+use G::DB::SDB;
+use G::Messenger;
 
 our @EXPORT = qw(
 		 help
@@ -58,6 +60,7 @@ our @EXPORT = qw(
 #::::::::::::::::::::::::::::::
 
 my %pdoc;
+my %gclass;
 
 #::::::::::::::::::::::::::::::
 #    Let the code begin...
@@ -65,6 +68,19 @@ my %pdoc;
 
 
 sub buildHelpDB{
+    require Bio::Root::Version;
+    require G::IO;
+
+    my $bpv = $Bio::Root::Version::VERSION;
+    my $gv  = $G::IO::VERSION;
+
+    if(sdb_exists("pdoc-bp$bpv-g$gv") && sdb_exists("gclass-$gv")){
+	%pdoc = %{sdb_load("pdoc-bp$bpv-g$gv")};
+	%gclass = %{sdb_load("gclass-$gv")};
+
+	return;
+    }
+
     my $bpPath = qx/perldoc -l Bio::Perl/;
     my $gPath = qx/perldoc -l G::IO/;
     my $rcmdPath = qx/perldoc -l Rcmd::Clustering/;
@@ -82,6 +98,9 @@ sub buildHelpDB{
     find({"wanted"=>\&process_g, "follow"=>1}, $rcmdPath . '.pm');
     find({"wanted"=>\&process_g, "follow"=>1}, $rcmdPath);
     find({"wanted"=>\&process_bp, "follow"=>1}, $bpPath);
+
+    sdb_save(\%pdoc, "pdoc-bp$bpv-g$gv");
+    sdb_save(\%gclass, "gclass-$gv");
 }
 
 
@@ -113,6 +132,7 @@ sub buildHelpDB{
     Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
+   20080214-01 replaced print with msg_send, and also returns the string
    20070531-01 initial posting
 
 =cut
@@ -165,60 +185,71 @@ sub help{
 	    }
 	}
 
-	print $ans;
-
+	msg_send($ans);
 
+	return $ans;
     }else{
 
-	my $ans = $pdoc{$key};
+        my $ans = $pdoc{$key};
 
-	if(length $ans){
-	    $ans =~ s/\_\_\%\%\%\%\%\_\_/\n/g;
+        if(length $ans){
+            $ans =~ s/\_\_\%\%\%\%\%\_\_/\n/g;
 
-	    unless($ans =~ /Name: (.*)   -   (.*)\n/){
-		$ans = "\n  Name: $key\n". $ans;
-	    }
-	}else{
-	    $ans = "     Keyword: \"$key\" not found in manual.\n\n";
-	    my $lckey = lc($key);
-	    my @tmp;;
-	    
-	    foreach my $keyword (sort keys %pdoc){
-		if(lc($keyword) =~ /$lckey/){
-		    push(@tmp, $keyword);
-		}
-	    }
-	    
-	    unless(scalar(@tmp)){
-		foreach my $keyword (sort keys %pdoc){
-		    if(amatch($lckey, ['i 1'], lc($keyword))){
-			push(@tmp, $keyword);
-		    }
-		}
-	    }
+            unless($ans =~ /Name: (.*)   -   (.*)\n/){
+                $ans = "\n  Name: $key\n". $ans;
+            }
+        }else{
+            $ans = "     Keyword: \"$key\" not found in manual.\n\n";
+            my $lckey = lc($key);
+            my @tmp;;
+            
+            foreach my $keyword (sort keys %pdoc){
+                if(lc($keyword) =~ /$lckey/){
+                    push(@tmp, $keyword);
+                }
+            }
+            
+            unless(scalar(@tmp)){
+                foreach my $keyword (sort keys %pdoc){
+                    if(amatch($lckey, ['i 1'], lc($keyword))){
+                        push(@tmp, $keyword);
+                    }
+                }
+            }
 
-	    if(scalar(@tmp)){
-		$ans .= "     Did you mean:\n";
-		
-		foreach my $entry (@tmp){
-		    $ans .= "              " . $entry . "\n";
-		}
-	    }
+            if(scalar(@tmp)){
+                $ans .= "     Did you mean:\n";
+                
+                foreach my $entry (@tmp){
+                    $ans .= "              " . $entry . "\n";
+                }
+            }
 
-	    $ans .= "\n\n      use \"help -s\" if you want to search, or \"help help\" if desperate.\n";
+            $ans .= "\n\n      use \"help -s\" if you want to search, or \"help help\" if desperate.\n";
 	}
 
-	print $ans;
+	msg_send($ans);
+	return $ans;
     }
 }
 
 sub process_g{
     next unless(/\.pm$/);
 
+    my $class = 'G';
+
+    if ($File::Find::name =~ /\/([G|SubOpt|Rcmd].*)\.pm$/){
+	$class = $1;
+	$class =~ s/\//::/g;
+    }else{
+	next;
+    }
+
     open(FILE, $File::Find::name) || die($File::Find::name, " ", $!);
     while(<FILE>){
 	chomp;
 	if(/^\s*\=head2\s+(.*)\s*$/){
+	    $gclass{$class . '::' . $1} = $1;
 	    my $subname = $1;
 
 	    while(<FILE>){
