@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: CHI.pm,v 1.1.1.1 2002/04/02 20:25:43 gaou Exp $
@@ -35,18 +33,13 @@ use SubOpt;
 use G::Messenger;
 
 use strict("vars");
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-
+use base qw(Exporter);
 use SelfLoader;
 
-require Exporter;
-
-@ISA = qw(Exporter AutoLoader);
-
-@EXPORT = qw(
-	CHI_parser
-	CHI_scripter
-	CHI_engine
+our @EXPORT = qw(
+		 CHI_parser
+		 CHI_scripter
+		 CHI_engine
 );
 
 __DATA__
@@ -351,37 +344,4 @@ sub CHI_engine{
 }
 
 
-sub DESTROY {
-    my $self = shift;
-}
-
 1;
-__END__
-# Below is the stub of documentation for your module. You better edit it!
-
-=head1 NAME
-
-G::System::CHI - Perl extension for blah blah blah
-
-=head1 SYNOPSIS
-
-  use G::System::CHI;
-  blah blah blah
-
-=head1 DESCRIPTION
-
-Stub documentation for G::System::CHI was created by h2xs. It looks like the
-author of the extension was negligent enough to leave the stub
-unedited.
-
-Blah blah blah.
-
-=head1 AUTHOR
-
-A. U. Thor, a.u.thor@a.galaxy.far.far.away
-
-=head1 SEE ALSO
-
-perl(1).
-
-=cut
