@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 # G-language GAE is free software; you can redistribute it and/or
@@ -30,20 +28,19 @@
 package G::Tools::GMap;
 
 use strict;
-use File::Basename;
-use File::Copy;
+use base qw(Exporter);
+use autouse 'File::Basename'=>qw(basename);
+use SelfLoader;
 
 use SubOpt;
 use G::Messenger;
 
-require Exporter;
-
-our @ISA = qw(Exporter);
-
 our @EXPORT = qw(
 		 generateGMap
 		 );
 
+__DATA__
+
 #::::::::::::::::::::::::::::::
 #          Perldoc
 #::::::::::::::::::::::::::::::
