@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 # G-language GAE is free software; you can redistribute it and/or
@@ -30,7 +28,7 @@
 package Rcmd::Clustering;
 
 use strict;
-use Carp qw(croak);
+use autouse 'Carp'=>qw(croak);
 
 use SubOpt;
 use G::Messenger;
@@ -165,7 +163,7 @@ sub som{
 		);
 
     my @result;
-    open(FILE, $rcmd->{log}) || ($!);
+    open(FILE, $rcmd->{log}) || die($!);
     while(<FILE>){
 	if(/qerror/){
 	    @result = ();
