@@ -42,7 +42,7 @@ our @EXPORT = qw(
 		 opt_as_gb
 );
 
-our $VERSION = '0.10';
+our $VERSION = '0.30';
 
 #::::::::::::::::::::::::::::::
 #          Variables
@@ -60,8 +60,7 @@ sub opt_as_gb {
 	&msg_error("Error 1 in SubOpt::opt_as_gb():\n  Given value is not a valid sequence.\n");
 	return '';
     }elsif (length $_[0] < 1){
-	&msg_error("Error 2 in SubOpt::opt_as_gb():\n  Given value is NULL.\n");
-	die;
+	return lastInstance G::IO();
     }
 
     my $unknown = shift @_;
@@ -100,7 +99,12 @@ sub opt_default{
 
 sub opt_val{
     my $key = shift;
-    return $data{$key};
+
+    if(length($key)){
+	return $data{$key};
+    }else{
+	return %data;
+    }
 }
 
 sub opt_get{
@@ -114,8 +118,13 @@ sub opt_get{
 
     while(defined $args[$i]){
 	if (substr($args[$i], 0, 1) eq '-' && substr($args[$i], 1, 1) !~ /[0-9]/){
-	    $data{substr($args[$i],1)} = $args[$i + 1];
-	    $i += 2;
+	    if(!defined($args[$i + 1]) || substr($args[$i + 1], 0, 1) eq '-' && substr($args[$i + 1], 1, 1) !~ /[0-9]/){
+		$data{substr($args[$i], 1)} = 1;
+		$i ++;
+	    }else{
+		$data{substr($args[$i],1)} = $args[$i + 1];
+		$i += 2;
+	    }
         }else{
 	    my $ref = ref $args[$i];
 	    if ($ref =~ /Bio::Seq/){
